@@ -28,7 +28,7 @@ sub iterate {
 
     while( my ( $key, $item ) = each( %$value ) ) {
 
-        eval { $code -> ( $item, $key, sub { $clone{ $key } = $_[ 0 ] } ) };
+        eval { $code -> ( $item, $key, \$clone{ $key } ) };
 
         if( $@ ) {
 
